Index: trunk/BNC/src/rinex/reqcanalyze.cpp
===================================================================
--- trunk/BNC/src/rinex/reqcanalyze.cpp	(revision 10614)
+++ trunk/BNC/src/rinex/reqcanalyze.cpp	(revision 10630)
@@ -64,5 +64,5 @@
   _logFileName     = settings.value("reqcOutLogFile").toString(); expandEnvVar(_logFileName);
   _logFile         = 0;
-  _log             = 0;
+  _logStream       = 0;
   _currEpo         = 0;
   _obsFileNames    = settings.value("reqcObsFile").toString().split(",", Qt::SkipEmptyParts);
@@ -95,5 +95,5 @@
     delete _ephs[ii];
   }
-  delete _log;     _log     = 0;
+  delete _logStream; _logStream = 0;
   delete _logFile; _logFile = 0;
   if (BNC_CORE->mode() != t_bncCore::interactive) {
@@ -114,20 +114,20 @@
     _logFile = new QFile(_logFileName);
     if (_logFile->open(QIODevice::WriteOnly | QIODevice::Text)) {
-      _log = new QTextStream();
-      _log->setDevice(_logFile);
-    }
-  }
-
-  if (_log) {
-    *_log << "QC Format Version  : " << QString("%1").arg(QC_FORMAT_VERSION,3,'f',1)  << Qt::endl << Qt::endl;
+      _logStream = new QTextStream();
+      _logStream->setDevice(_logFile);
+    }
+  }
+
+  if (_logStream) {
+    *_logStream << "QC Format Version  : " << QString("%1").arg(QC_FORMAT_VERSION,3,'f',1)  << Qt::endl << Qt::endl;
   }
 
   // Initialize RINEX Observation Files
   // ----------------------------------
-  t_reqcEdit::initRnxObsFiles(_obsFileNames, _rnxObsFiles, _log);
+  t_reqcEdit::initRnxObsFiles(_obsFileNames, _rnxObsFiles, _logStream);
 
   // Read Ephemerides
   // ----------------
-  t_reqcEdit::readEphemerides(_navFileNames, _ephs, _log, _checkEph);
+  t_reqcEdit::readEphemerides(_navFileNames, _ephs, _logStream, _checkEph);
 
   // Loop over all RINEX Files
@@ -225,6 +225,6 @@
   }
   catch (QString str) {
-    if (_log) {
-      *_log << "Exception " << str << Qt::endl;
+    if (_logStream) {
+      *_logStream << "Exception " << str << Qt::endl;
     }
     else {
@@ -733,5 +733,5 @@
 void t_reqcAnalyze::printReport(const t_rnxObsFile* obsFile) {
 
-  if (!_log) {
+  if (!_logStream) {
     return;
   }
@@ -742,5 +742,5 @@
   // Summary
   // -------
   *_log << "Observation File   : " << obsFileName                                   << Qt::endl
         << "RINEX Version      : " << QString("%1").arg(obsFile->version(),4,'f',2) << Qt::endl
         << "Marker Name        : " << _qcFile._markerName                           << Qt::endl
@@ -766,10 +766,10 @@
     char sys = obsFile->system(iSys);
     if (sys != ' ') {
-      *_log << "Observation Types " << sys << ":";
+      *_logStream << "Observation Types " << sys << ":";
       for (int iType = 0; iType < obsFile->nTypes(sys); iType++) {
         QString type = obsFile->obsType(sys, iType);
-        *_log << " " << type;
-      }
-      *_log << Qt::endl;
+        *_logStream << " " << type;
+      }
+      *_logStream << Qt::endl;
     }
   }
@@ -785,11 +785,11 @@
     systemMap[prn.system()].push_back(&qcSatSum);
   }
-  *_log << "Analysed GNSS      : " << systemMap.size() << "   ";
+  *_logStream << "Analysed GNSS      : " << systemMap.size() << "   ";
   QMapIterator<QChar, QVector<const t_qcSatSum*> > itSys(systemMap);
   while (itSys.hasNext()) {
     itSys.next();
-    *_log << ' ' << itSys.key();
-  }
-  *_log << Qt::endl;
+    *_logStream << ' ' << itSys.key();
+  }
+  *_logStream << Qt::endl;
 
 
@@ -819,5 +819,5 @@
       }
     }
-    *_log << Qt::endl
+    *_logStream << Qt::endl
           << prefixSys << "Satellites: " << qcSatVec.size() << Qt::endl
           << prefixSys << "Signals   : " << frqMap.size() << "   ";
@@ -826,7 +826,7 @@
       itFrq.next();
       QString frqType = itFrq.key(); if (frqType.length() < 2) frqType += '?';
-      *_log << ' ' << frqType;
-    }
-    *_log << Qt::endl;
+      *_logStream << ' ' << frqType;
+    }
+    *_logStream << Qt::endl;
     QString prefixSys2 = "    " + prefixSys;
     itFrq.toFront();
@@ -864,13 +864,13 @@
       double ratio = (double(numObs) / double(numExpectedObs)) * 100.0;
 
-      *_log << Qt::endl
+      *_logStream << Qt::endl
             << prefixSys2 << prefixFrq << "Observations      : ";
       if(_navFileNames.isEmpty() || numExpectedObs == 0.0  || _navFileIncomplete.contains(sys.toLatin1())) {
-        *_log << QString("%1\n").arg(numObs,           6);
+        *_logStream << QString("%1\n").arg(numObs,           6);
       }
       else {
-        *_log << QString("%1 (%2) %3 \%\n").arg(numObs,           6).arg(numExpectedObs,           8).arg(ratio, 8, 'f', 2);
-      }
-      *_log << prefixSys2 << prefixFrq << "Slips (file+found): " << QString("%1 +").arg(numSlipsFlagged,  8)
+        *_logStream << QString("%1 (%2) %3 \%\n").arg(numObs,           6).arg(numExpectedObs,           8).arg(ratio, 8, 'f', 2);
+      }
+      *_logStream << prefixSys2 << prefixFrq << "Slips (file+found): " << QString("%1 +").arg(numSlipsFlagged,  8)
                                                                  << QString("%1\n").arg(numSlipsFound,    8)
             << prefixSys2 << prefixFrq << "Gaps              : " << QString("%1\n").arg(numGaps,          8)
@@ -886,5 +886,5 @@
     return;
   }
-  *_log << Qt::endl;
+  *_logStream << Qt::endl;
   for (int iEpo = 0; iEpo < _qcFile._qcEpo.size(); iEpo++) {
     const t_qcEpo& qcEpo = _qcFile._qcEpo[iEpo];
@@ -904,5 +904,5 @@
       .arg(sec,  11, 'f', 7);
 
-    *_log << dateStr << QString(" %1").arg(qcEpo._qcSat.size(), 2)
+    *_logStream << dateStr << QString(" %1").arg(qcEpo._qcSat.size(), 2)
           << QString(" %1").arg(qcEpo._PDOP, 4, 'f', 1)
           << Qt::endl;
@@ -914,5 +914,5 @@
       const t_qcSat& qcSat = itSat.value();
 
-      *_log << prn.toString().c_str()
+      *_logStream << prn.toString().c_str()
             << QString(" %1 %2").arg(qcSat._eleDeg, 6, 'f', 2).arg(qcSat._azDeg, 7, 'f', 2);
 
@@ -927,39 +927,39 @@
         }
       }
-      *_log << QString("  %1").arg(numObsTypes, 2);
+      *_logStream << QString("  %1").arg(numObsTypes, 2);
 
       for (int iFrq = 0; iFrq < qcSat._qcFrq.size(); iFrq++) {
         const t_qcFrq& qcFrq = qcSat._qcFrq[iFrq];
         if (qcFrq._phaseValid) {
-          *_log << "  L" << qcFrq._rnxType2ch << ' ';
+          *_logStream << "  L" << qcFrq._rnxType2ch << ' ';
           if (qcFrq._slip) {
-            *_log << 's';
+            *_logStream << 's';
           }
           else {
-            *_log << '.';
+            *_logStream << '.';
           }
           if (qcFrq._gap) {
-            *_log << 'g';
+            *_logStream << 'g';
           }
           else {
-            *_log << '.';
-          }
-          *_log << QString(" %1").arg(qcFrq._SNR,   4, 'f', 1);
+            *_logStream << '.';
+          }
+          *_logStream << QString(" %1").arg(qcFrq._SNR,   4, 'f', 1);
         }
         if (qcFrq._codeValid) {
-          *_log << "  C" << qcFrq._rnxType2ch << ' ';
+          *_logStream << "  C" << qcFrq._rnxType2ch << ' ';
           if (qcFrq._gap) {
-            *_log << " g";
+            *_logStream << " g";
           }
           else {
-            *_log << " .";
-          }
-          *_log << QString(" %1").arg(qcFrq._stdMP, 3, 'f', 2);
-        }
-      }
-      *_log << Qt::endl;
-    }
-  }
-  _log->flush();
+            *_logStream << " .";
+          }
+          *_logStream << QString(" %1").arg(qcFrq._stdMP, 3, 'f', 2);
+        }
+      }
+      *_logStream << Qt::endl;
+    }
+  }
+  _logStream->flush();
 }
 
@@ -742,5 +742,5 @@
   // Summary
   // -------
-  *_log << "Observation File   : " << obsFileName                                   << Qt::endl
+  *_logStream << "Observation File   : " << obsFileName                                   << Qt::endl
         << "RINEX Version      : " << QString("%1").arg(obsFile->version(),4,'f',2) << Qt::endl
         << "Marker Name        : " << _qcFile._markerName                           << Qt::endl
